@@ -1,21 +1,22 @@
 use agui_core::{
     context::WidgetContext,
-    layout::LayoutRef,
-    widget::{BuildResult, WidgetImpl, WidgetRef},
+    layout::Layout,
+    widget::{BuildResult, WidgetBuilder, WidgetRef},
+    Ref,
 };
 use agui_macros::Widget;
 
-#[derive(Debug, Default, Widget)]
+#[derive(Default, Widget)]
 #[widget(layout = "column")]
 pub struct Column {
-    pub layout: LayoutRef,
+    pub layout: Ref<Layout>,
 
     pub children: Vec<WidgetRef>,
 }
 
-impl WidgetImpl for Column {
+impl WidgetBuilder for Column {
     fn build(&self, ctx: &WidgetContext) -> BuildResult {
-        ctx.set_layout(LayoutRef::clone(&self.layout));
+        ctx.set_layout(Ref::clone(&self.layout));
 
         (&self.children).into()
     }
