@@ -1,24 +1,31 @@
 use agui_core::{
     context::WidgetContext,
-    layout::LayoutRef,
+    layout::Layout,
     unit::Color,
-    widget::{BuildResult, WidgetImpl, WidgetRef},
+    widget::{BuildResult, WidgetBuilder, WidgetRef},
+    Ref,
 };
 use agui_macros::Widget;
 
-#[derive(Debug, Default, Widget)]
-pub struct Quad {
-    pub layout: LayoutRef,
+#[derive(Clone, Default)]
+pub struct QuadStyle {
     pub color: Color,
+}
 
+#[derive(Default, Widget)]
+pub struct Quad {
+    pub layout: Ref<Layout>,
     pub clip: bool,
+
+    pub style: QuadStyle,
+
     pub child: WidgetRef,
 }
 
-impl WidgetImpl for Quad {
+impl WidgetBuilder for Quad {
     fn build(&self, ctx: &WidgetContext) -> BuildResult {
-        ctx.set_layout(LayoutRef::clone(&self.layout));
+        ctx.set_layout(Ref::clone(&self.layout));
 
         (&self.child).into()
     }
-}
\ No newline at end of file
+}
