@@ -1,17 +1,17 @@
 use agui_core::{
     context::WidgetContext,
     unit::Sizing,
-    widget::{BuildResult, WidgetImpl},
+    widget::{BuildResult, WidgetBuilder},
 };
 use agui_macros::Widget;
 
-#[derive(Debug, Default, Widget)]
+#[derive(Default, Widget)]
 pub struct Text {
     pub size: Sizing,
     pub text: String,
 }
 
-impl WidgetImpl for Text {
+impl WidgetBuilder for Text {
     fn build(&self, _ctx: &WidgetContext) -> BuildResult {
         BuildResult::Empty
     }
